==> click-1.2.3.tar.gz: click-1.2.3/elements/linuxmodule/schedulelinux.cc <==
/*
 * schedulelinux.{cc,hh} -- go back to linux scheduler
 *
 * Copyright (c) 1999-2000 Massachusetts Institute of Technology
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, subject to the conditions
 * listed in the Click LICENSE file. These conditions include: you must
 * preserve this copyright notice, and you cannot mention the copyright
 * holders in advertising related to the Software without their permission.
 * The Software is provided WITHOUT ANY WARRANTY, EXPRESS OR IMPLIED. This
 * notice is a summary of the Click LICENSE file; the license in that file is
 * legally binding.
 */

#include <click/config.h>
#include <click/router.hh>
#include <click/standard/scheduleinfo.hh>
#include "schedulelinux.hh"
#include <click/confparse.hh>
#include <click/error.hh>
#include <click/glue.hh>
#include <unistd.h>

ScheduleLinux::ScheduleLinux()
  : _task(this)
{
  MOD_INC_USE_COUNT;
}

ScheduleLinux::~ScheduleLinux()
{
  MOD_DEC_USE_COUNT;
}

ScheduleLinux *
ScheduleLinux::clone() const
{
  return new ScheduleLinux();
}

int
ScheduleLinux::configure(const Vector<String> &conf, ErrorHandler *errh)
{
  return cp_va_parse(conf, this, errh, cpEnd);
}

int
ScheduleLinux::initialize(ErrorHandler *errh)
{
  ScheduleInfo::join_scheduler(this, &_task, errh);
  return 0;
}

void
ScheduleLinux::run_scheduled()
{
  schedule();
  _task.fast_reschedule();
}

void
ScheduleLinux::add_handlers()
{
  add_task_handlers(&_task);
}

ELEMENT_REQUIRES(linuxmodule)
EXPORT_ELEMENT(ScheduleLinux)

==> click-1.4.3.tar.gz: click-1.4.3/elements/linuxmodule/schedulelinux.cc <==
/*
 * schedulelinux.{cc,hh} -- go back to linux scheduler
 *
 * Copyright (c) 1999-2000 Massachusetts Institute of Technology
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, subject to the conditions
 * listed in the Click LICENSE file. These conditions include: you must
 * preserve this copyright notice, and you cannot mention the copyright
 * holders in advertising related to the Software without their permission.
 * The Software is provided WITHOUT ANY WARRANTY, EXPRESS OR IMPLIED. This
 * notice is a summary of the Click LICENSE file; the license in that file is
 * legally binding.
 */

#include <click/config.h>
#include <click/router.hh>
#include <click/standard/scheduleinfo.hh>
#include "schedulelinux.hh"
#include <click/confparse.hh>
#include <click/error.hh>
#include <click/glue.hh>

ScheduleLinux::ScheduleLinux()
  : _task(this)
{
  MOD_INC_USE_COUNT;
}

ScheduleLinux::~ScheduleLinux()
{
  MOD_DEC_USE_COUNT;
}

int
ScheduleLinux::configure(Vector<String> &conf, ErrorHandler *errh)
{
  return cp_va_parse(conf, this, errh, cpEnd);
}

int
ScheduleLinux::initialize(ErrorHandler *errh)
{
  ScheduleInfo::join_scheduler(this, &_task, errh);
  return 0;
}

bool
ScheduleLinux::run_task()
{
  schedule();
  _task.fast_reschedule();
  return true;
}

void
ScheduleLinux::add_handlers()
{
  add_task_handlers(&_task);
}

ELEMENT_REQUIRES(linuxmodule)
EXPORT_ELEMENT(ScheduleLinux)
